@@ -1,8 +1,6 @@
 import time
 import math
 
-SPINNER_FRAMES = ["\u25DC ", " \u25DD", " \u25DE", "\u25DF "]
-
 
 def bar(current_progress: int,
         total=100,
@@ -19,36 +17,36 @@ def bar(current_progress: int,
     percentage = current_progress / (total / 100)
     q = math.floor(percentage / (100 / bar_length))
     remaining = bar_length - q
-    bar = f'{icon * q}{" "*remaining}'
+    bar = f'{icon * min(q, bar_length)}{" "*remaining}'
     if show_percentage:
         print(f'\r{bar} {round(percentage, 1)} %', end='')
     else:
         print(f'\r{bar}', end='')
 
 
-def spinner():
+def spinner(icons=["\u25DC ", " \u25DD", " \u25DE", "\u25DF "]):
     '''
     Returns a spinner Generator. 
     Pass the instance of this to next() to print the next frame of the spinner.
     '''
     current_index = 0
     while 1:
-        if current_index >= len(SPINNER_FRAMES) - 1:
+        if current_index >= len(icons) - 1:
             current_index = 0
         else:
             current_index += 1
-        yield print(f'\r{SPINNER_FRAMES[current_index]}', end='')
+        yield print(f'\r{icons[current_index]}', end='')
 
 
 if __name__ == '__main__':
-    a = spinner()
-    max = 20
+    a = spinner(icons=['🌑', '🌒', '🌓', '🌔', '🌕', '🌖', '🌗', '🌘'])
+    max = 100
     for i in range(0, max):
         next(a)
         time.sleep(0.035)
     print('\r', end='')
 
     for i in range(0, max+1):
-        bar(i, total=max, bar_length=65, show_percentage=True)
+        bar(i, total=max, bar_length=20, show_percentage=True)
         time.sleep(0.035)
     print()
